==> foundation-2.6.1.tgz: package/SocialGameCenter/SocialGameCenter.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialGameCenter = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M79 14H21a7 7 0 00-7 7v58a7 7 0 007 7h58a7 7 0 007-7V21a7 7 0 00-7-7zm-23.045 5.229c10.658 0 19.298 8.641 19.298 19.299a19.2 19.2 0 01-3.482 11.039 16.854 16.854 0 00-10.465-3.634c-6.582 0-12.275 3.76-15.082 9.242-5.718-3.35-9.568-9.541-9.568-16.646 0-10.659 8.64-19.3 19.299-19.3zM19.852 46.931c0-11.635 8.755-21.22 20.036-22.54-3.324 3.774-5.356 8.713-5.356 14.138 0 7.981 4.373 14.928 10.845 18.614a17.449 17.449 0 00-.64 2.295 11.95 11.95 0 00-3.429-.505c-4.89 0-9.088 2.941-10.937 7.148-6.323-4.03-10.519-11.098-10.519-19.15zm21.454 34.145c-5.632 0-10.197-4.564-10.197-10.197 0-5.631 4.565-10.196 10.197-10.196 5.631 0 10.197 4.565 10.197 10.196 0 5.633-4.566 10.197-10.197 10.197zm20-3.25a14.862 14.862 0 01-8.782-2.87c.463-1.274.729-2.643.729-4.077 0-4.689-2.708-8.735-6.639-10.691 1.269-6.968 7.357-12.255 14.693-12.255 8.255 0 14.947 6.692 14.947 14.946-.001 8.256-6.693 14.947-14.948 14.947z"
  }));
});
SocialGameCenter.displayName = 'SocialGameCenter';
export const SocialGameCenterDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialGameCenter/SocialGameCenter.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialGameCenter = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M79 14H21a7 7 0 00-7 7v58a7 7 0 007 7h58a7 7 0 007-7V21a7 7 0 00-7-7zm-23.045 5.229c10.658 0 19.298 8.641 19.298 19.299a19.2 19.2 0 01-3.482 11.039 16.854 16.854 0 00-10.465-3.634c-6.582 0-12.275 3.76-15.082 9.242-5.718-3.35-9.568-9.541-9.568-16.646 0-10.659 8.64-19.3 19.299-19.3zM19.852 46.931c0-11.635 8.755-21.22 20.036-22.54-3.324 3.774-5.356 8.713-5.356 14.138 0 7.981 4.373 14.928 10.845 18.614a17.449 17.449 0 00-.64 2.295 11.95 11.95 0 00-3.429-.505c-4.89 0-9.088 2.941-10.937 7.148-6.323-4.03-10.519-11.098-10.519-19.15zm21.454 34.145c-5.632 0-10.197-4.564-10.197-10.197 0-5.631 4.565-10.196 10.197-10.196 5.631 0 10.197 4.565 10.197 10.196 0 5.633-4.566 10.197-10.197 10.197zm20-3.25a14.862 14.862 0 01-8.782-2.87c.463-1.274.729-2.643.729-4.077 0-4.689-2.708-8.735-6.639-10.691 1.269-6.968 7.357-12.255 14.693-12.255 8.255 0 14.947 6.692 14.947 14.946-.001 8.256-6.693 14.947-14.948 14.947z"
  }));
});
SocialGameCenter.displayName = 'SocialGameCenter';
export var SocialGameCenterDimensions = {
  height: 100,
  width: 100
};
